# Notes #

Code in this directory comes from (or is derived from) the super-cool Picard project.

[Picard](https://github.com/metabrainz/picard)

I'd like to express my thanks to all of have contributed to that project.

Note: we could have just set the Picard library as a dependency of audiolibrarian, but
it includes other dependencies (such as PyQT) that add a lot of overhead not required
by this project.
